//+++++++++++++++++++++++
//+++++++++++++++++++++++
//+++++++++++++++++++++++
// START INTERFACES START
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// END INTERFACES
//+++++++++++++++++++++++
//+++++++++++++++++++++++
//+++++++++++++++++++++++
// window['marks'] = [];
chrome.storage.sync.set({ marks: [] });
//+++++++++++++++++++++++
//+++++++++++++++++++++++
//+++++++++++++++++++++++
// START CHROME STUFF
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    chrome.storage.sync.get(['marks'], result => {
        const newMarks = [...result.marks, request.selection];
        chrome.storage.sync.set({ marks: [...result.marks, request.selection] });
        sendResponse(newMarks);
    });
});
// chrome.runtime.onStartup.addListener(() => {
// });
// Listen for context menu to create mark
chrome.contextMenus.onClicked.addListener((e) => __awaiter(this, void 0, void 0, function* () {
    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
        e.selectionText ?
            chrome.tabs.sendMessage(tabs[0].id, {
                id: 'contextMenu',
                detail: e.selectionText
            }) : chrome.tabs.sendMessage(tabs[0].id, {
            id: 'savePageAsBookmark',
            detail: e.selectionText
        });
    });
}));
const filteredTabs = (tabs) => tabs.filter(_tab => !(_tab.url.startsWith('chrome://') || _tab.url.includes('https://chrome.google.com')));
/**
 * Inits the marks on the tabs
 * @param queryInfo { active } - If active = true, only active window (max. 1) is shown, else all open tabs are shown
 */
function initMarks(queryInfo) {
    chrome.tabs.query(queryInfo || { active: true }, (tabs) => {
        filteredTabs(tabs).forEach(tab => {
            chrome.storage.sync.get(['marks'], result => {
                const marks = result.marks.filter(mark => mark.url === tab.url);
                chrome.tabs.sendMessage(tab.id, {
                    id: 'init',
                    marks: marks
                });
            });
        });
    });
}
// Sends message to current contentScript when page changes
chrome.tabs.onUpdated.addListener(() => {
    initMarks();
});
/**
 * When installing the chrome extension the content scripts have to be manually injected
 * to make the marker directly appear without reloading.
 */
function injectContentScripts() {
    chrome.tabs.query({}, (tabs) => {
        filteredTabs(tabs).forEach(tab => {
            try {
                const contentScripts = chrome.runtime.getManifest().content_scripts[0].js;
                contentScripts.forEach(contentScript => {
                    try {
                        // @ts-ignore
                        chrome.scripting.executeScript({
                            target: { tabId: tab.id },
                            files: [contentScript],
                        }, () => { console.log(`Successfully injected content script ${contentScript}`); });
                    }
                    catch (error) {
                        console.log(error);
                    }
                });
            }
            catch (error) {
                console.log(error);
            }
        });
    });
}
chrome.runtime.onInstalled.addListener(function () {
    initMarks();
    injectContentScripts();
    chrome.contextMenus.create({
        id: "selection",
        title: "Save: ' %s '",
        contexts: ["selection"]
    });
    chrome.contextMenus.create({
        id: "savePageAsBookmark",
        title: "Save page as bookmark",
        contexts: ["page"]
    });
});
chrome.storage.onChanged.addListener(function (changes, namespace) {
    for (var key in changes) {
        var storageChange = changes[key];
    }
});
//# sourceMappingURL=background.js.map