var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { connect } from 'pwa-helpers';
import { store } from './../store/store';
import { MarkerService } from './../services/marker.service';
import { css, customElement, html, LitElement, property, unsafeCSS } from 'lit-element';
import { highlightMarks, createMyMarkerComponent, createMark } from '../helper/markerHelper';
import { BookmarkService } from '../services/bookmark.service';
const componentCSS = require('./app.component.scss');
let WebMarker = class WebMarker extends connect(store)(LitElement) {
    constructor() {
        super(...arguments);
        this.show = false;
        this.showMarkerIsDisabled = false;
        /**
         * Can be set to true to hide side-bar icon. E.g. in full screen mode
         *
         * @memberof WebMarker
         */
        this.hide = false;
        /**
         * Set width of menu in px to calculate center.
         * Only for making new marks.
         *
         * @memberof WebMarker
         */
        this.menuWidth = 80;
        this.markerService = new MarkerService();
        this.bookmarkService = new BookmarkService();
    }
    firstUpdated() {
        return __awaiter(this, void 0, void 0, function* () {
            if (document.readyState === "complete") {
                yield highlightMarks();
            }
            else {
                document.onreadystatechange = () => __awaiter(this, void 0, void 0, function* () {
                    if (document.readyState === "complete" || document.readyState === "interactive") {
                        document.onreadystatechange = null;
                        yield highlightMarks();
                    }
                });
            }
            this.listenToShowMarker();
            this.listenForContextMenu();
            this.listenForFullscreen();
        });
    }
    stateChanged() {
        return __awaiter(this, void 0, void 0, function* () {
            if (store.getState().loggedIn) {
                this.marks = store.getState().marks;
            }
            else {
                this.marks = [];
            }
        });
    }
    /**
     * Hides the icon on fullscreen mode
     *
     * @memberof WebMarker
     */
    listenForFullscreen() {
        window.addEventListener("resize", () => {
            this.hide = false;
            if (window.innerHeight == screen.height) {
                this.hide = true;
            }
        });
    }
    listenForContextMenu() {
        try {
            chrome.runtime.onMessage.addListener((request) => __awaiter(this, void 0, void 0, function* () {
                if (request.id === 'contextMenu' && request.detail) {
                    const mark = createMark(store.getState().highlightColor);
                    createMyMarkerComponent(mark);
                    yield this.markerService.createMark(mark);
                }
                ;
                if (request.id === 'savePageAsBookmark') {
                    const newBookmark = this.bookmarkService.createNewBookmark(true);
                    yield this.bookmarkService.createBookmark(newBookmark);
                }
                ;
            }));
        }
        catch (error) {
            // Chrome extension not available
        }
    }
    /**
     * Listens for click and selection events to show or hide the marker
     *
     * @memberof WebMarker
     */
    listenToShowMarker() {
        document.addEventListener('selectionchange', (e) => {
            const selectionText = window.getSelection().toString();
            if (!selectionText.length)
                this.show = false;
        });
        document.addEventListener('click', (e) => {
            const selectionText = window.getSelection().toString();
            if (!selectionText.length)
                this.show = false;
            else if (selectionText.length) {
                this.setPositionOfMarkerForClick(e);
            }
        });
        document.addEventListener('scroll', (e) => {
            this.show = false;
        });
    }
    /**
     *  Sets the position of the marker for a click event.
     *  Gets the center from the bounds of the createdRange
     *
     * @param {MouseEvent} e
     * @memberof WebMarker
     */
    setPositionOfMarkerForClick(e) {
        const rangeBounds = window.getSelection().getRangeAt(0).getBoundingClientRect();
        this.style.position = 'fixed';
        this.style.left = rangeBounds.left + (rangeBounds.width / 2) - (this.menuWidth / 2) - 35 + 'px';
        this.style.top = rangeBounds.top + 'px';
        this.show = true;
    }
    render() {
        return html `
  ${!this.hide ? html `
  <my-marker .show=${this.show && !this.showMarkerIsDisabled} .menuWidth=${this.menuWidth}></my-marker>
  ` : ''}
  `;
    }
};
WebMarker.styles = css `${unsafeCSS(componentCSS)}`;
__decorate([
    property()
], WebMarker.prototype, "marks", void 0);
__decorate([
    property()
], WebMarker.prototype, "show", void 0);
__decorate([
    property()
], WebMarker.prototype, "showMarkerIsDisabled", void 0);
__decorate([
    property()
], WebMarker.prototype, "hide", void 0);
__decorate([
    property()
], WebMarker.prototype, "newContextMark", void 0);
__decorate([
    property()
], WebMarker.prototype, "menuWidth", void 0);
WebMarker = __decorate([
    customElement('web-marker')
], WebMarker);
export { WebMarker };
//# sourceMappingURL=app.component.js.map