var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { store } from './../store/store';
import uuidv4 from 'uuid/v4';
import { getTitleForBookmark } from './bookmarkHelper';
import './rangy-updated/lib/rangy-classapplier';
import './rangy-updated/lib/rangy-highlighter';
import './rangy-updated/lib/rangy-textrange';
import './rangy-updated/lib/rangy-serializer';
import './rangy-updated/lib/rangy-selectionsaverestore';
import rangy from './rangy-updated';
import { MarkerService } from '../services/marker.service';
import { initBookmarks, initMarks } from '../store/actions';
import { BookmarkService } from '../services/bookmark.service';
function onElementCreate(el, mark) {
    el['markId'] = mark.id;
    if (mark.color) {
        el.style.backgroundColor = mark.color;
    }
    el.setAttribute('markId', mark.id);
}
/**
 *  Scroll to mark if there is a scrollY param in query url.
 *  SetTimeout to put at the end of event Loop
 * @memberof WebMarker
 */
export function scrollToMark() {
    setTimeout(() => {
        try {
            const params = location.href.split('?')[1].split('=');
            params.forEach((param, index) => {
                if (param === 'scrollY') {
                    const scrollOptions = {
                        top: Number(params[index + 1]),
                        left: 0,
                        behavior: 'smooth'
                    };
                    window.scrollTo(scrollOptions);
                }
            });
        }
        catch (error) {
            //
        }
    });
}
/**
 *  This method loads all marks for current url from server
 *
 * @todo Load only marks with current url from server
 *
 * @memberof WebMarker
 */
export function highlightMarks() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            scrollToMark();
            const markerService = new MarkerService();
            const bookmarkService = new BookmarkService();
            // Get initial marks and bookmarks for current url
            const [marks, bookmark] = yield Promise.all([markerService.getMarksForUrl(location.href), bookmarkService.getBookmarkForUrl(location.href)]);
            initMarks(marks);
            initBookmarks([bookmark]);
            if (marks) {
                marks.sort(mark => mark.createdAt).map(mark => highlightText(null, mark));
            }
        }
        catch (error) {
            //
        }
    });
}
export function highlightText(range, mark) {
    try {
        //const markElement = markWithRangy(mark);
        addStyles();
        if (mark.rangyObject) {
            markWithRangy(mark);
        }
        else {
            // Supporting old marks, made without rangy
            const markElement = createMarkElement(range, mark);
            createMyMarkerComponent(mark, markElement);
        }
        createMyMarkerComponent(mark);
        // For animation purposes
    }
    catch (error) {
        //
    }
}
function markWithRangy(mark) {
    const selectionSerialized = mark.rangyObject;
    const highlighter = rangy.createHighlighter();
    const applier = rangy.createClassApplier('highlight', {
        onElementCreate: function (el) {
            onElementCreate(el, mark);
        }
    });
    highlighter.addClassApplier(applier);
    highlighter.deserialize(selectionSerialized);
    highlighter.highlightSelection('highlight', null, mark.id);
    rangy.getSelection().removeAllRanges();
}
/**
 * Creates the mark element to highlight text
 *
 * @param {Range} [range]
 * @param {Mark} [mark]
 * @returns
 */
function createMarkElement(range, mark) {
    mark ? range = recreateRange(mark) : range = range;
    const markElement = document.createElement('mark');
    markElement.setAttribute('markId', mark ? mark.id : '');
    markElement.appendChild(range.extractContents());
    range.insertNode(markElement);
    return markElement;
}
function recreateRange(mark) {
    const startContainer = findStartEndContainer(document.body, mark, true);
    const endContainer = findStartEndContainer(document.body, mark, false);
    const range = document.createRange();
    range.setStart(startContainer, mark.startOffset);
    range.setEnd(endContainer, mark.endOffset);
    return range;
}
/**
 * Fixes the issue when new created marks are added the serialized hash is not calculated correctly.
 * When reloading the page, there is an offset we want to prevent.
 * To fix that we need to subtract an offset of 2 for each mark, that is located before the new mark.
 * @param param0
 * @returns
 */
function getFixedSerializedSelection({ rangy, selectionSerialized }) {
    const regexStartOffset = /(?<=\|)(.*?)(?=\$)/;
    const startOffset = +regexStartOffset.exec(selectionSerialized)[0];
    const regexEndOffset = /(?<=\$)(.*?)(?=\$)/;
    const endOffSet = +regexEndOffset.exec(selectionSerialized)[0];
    if (rangy['createdOffsets']) {
        // Get all highlights, that are located before our new mark
        const customOffsetFix = rangy['createdOffsets'].filter(offset => offset < startOffset).length * 2;
        try {
            // serialized example: type:textContent|855$871$1$highlight$
            selectionSerialized = selectionSerialized.replace(/(?<=\|)(.*?)(?=\$)/, `${startOffset - customOffsetFix}`);
            selectionSerialized = selectionSerialized.replace(/(?<=\$)(.*?)(?=\$)/, `${endOffSet - customOffsetFix}`);
        }
        catch (error) {
            //
        }
    }
    rangy['createdOffsets'] = typeof rangy['createdOffsets'] === 'undefined' ? [startOffset] : [...rangy['createdOffsets'], startOffset];
    return selectionSerialized;
}
/**
 * If @param text is given the mark is created by the context menu
 *
 * @export
 * @param {string} [text]
 * @returns {Mark}
 */
export function createMark(color) {
    addStyles();
    const selection = window.getSelection();
    // If selection is made by my-menu popup
    // if (selection.toString()) {
    const range = selection.getRangeAt(0);
    const mark = {
        id: uuidv4(),
        url: location.href,
        origin: location.href,
        tags: [],
        text: selection.toString(),
        title: getTitleForBookmark(),
        anchorOffset: selection.anchorOffset,
        createdAt: new Date().getTime(),
        nodeData: range.startContainer.nodeValue,
        completeText: range.startContainer.parentElement.innerText,
        nodeTagName: range.startContainer.parentElement.tagName.toLowerCase(),
        startContainerText: range.startContainer.textContent,
        endContainerText: range.endContainer.textContent,
        startOffset: range.startOffset,
        endOffset: range.endOffset,
        scrollY: window.scrollY,
        rangyObject: '',
        color
    };
    let highlighter;
    highlighter = rangy.createHighlighter();
    rangy.saveSelection();
    const applier = rangy.createClassApplier('highlight', {
        onElementCreate: function (el) {
            onElementCreate(el, mark);
        }
    });
    highlighter.addClassApplier(applier);
    highlighter.highlightSelection('highlight', null, mark.id);
    let selectionSerialized = highlighter.serialize();
    highlighter.deserialize(selectionSerialized);
    rangy.getSelection().removeAllRanges();
    selectionSerialized = getFixedSerializedSelection({ rangy, selectionSerialized });
    mark.rangyObject = selectionSerialized;
    localStorage.setItem('mark', JSON.stringify(mark));
    return mark;
}
/**
 * Creates the mark in the DOM. Afterwards it listens for a deletion event to remove it.
 *
 * @param {HTMLElement} markElement
 * @param {Mark} mark
 */
export function createMyMarkerComponent(mark, markElement) {
    const myMarkElement = document.createElement('my-marker');
    myMarkElement.mark = mark;
    myMarkElement.setAttribute('markId', mark.id);
    if (!markElement) {
        markElement = document.evaluate(`.//span[@markid='${mark.id}']`, document.body, null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null).snapshotItem(0);
    }
    markElement.appendChild(myMarkElement);
    // Listen for state changes and delete mark from DOM if it got removed
    store.subscribe(() => {
        const lastAction = store.getState().lastAction;
        if (lastAction === 'REMOVE_MARK') {
            if (!store.getState().marks.find(e => e.id === mark.id)) {
                myMarkElement.remove();
                if (mark.rangyObject) {
                    deleteMarksFromDom(mark);
                }
                else {
                    deleteMarkFromDom(markElement);
                }
            }
        }
    });
}
export function deleteMarksFromDom(mark) {
    try {
        let spanHighlights = document.evaluate(`.//span[@markid='${mark.id}']`, document.body, null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);
        for (let i = 0; i < spanHighlights.snapshotLength; i++) {
            let markElement = spanHighlights.snapshotItem(i);
            // Unwraps the mark element
            const parent = markElement.parentNode;
            // move all children out of the element
            while (markElement.firstChild)
                parent.insertBefore(markElement.firstChild, markElement);
            // remove the empty element
            parent.removeChild(markElement);
        }
    }
    catch (error) {
        //
    }
}
export function deleteMarkFromDom(markElement) {
    try {
        // Unwraps the mark element
        const parent = markElement.parentNode;
        // move all children out of the element
        while (markElement.firstChild)
            parent.insertBefore(markElement.firstChild, markElement);
        // remove the empty element
        parent.removeChild(markElement);
    }
    catch (error) {
        //
    }
}
/**
 * Returns the StartContainer or EndContainer to recreate the range of the given mark
 *
 * @export
 * @param {HTMLElement} container
 * @param {Mark} mark
 * @param {boolean} start true = searchs for StartContainer; false = searchs for EndContainer
 * @returns {HTMLElement}
 */
export function findStartEndContainer(container, mark, start) {
    container ? container = container : container = document.body;
    let elements;
    try {
        elements = textNodesUnder(container);
        // tslint:disable-next-line: prefer-for-of
        for (let i = 0; i < elements.length; i++) {
            if (elements[i].textContent.includes(start ? mark.startContainerText : mark.endContainerText)) {
                return elements[i];
            }
        }
    }
    catch (error) {
        //
    }
}
/**
 * Returns all text nodes under an element
 *
 * @export
 * @param {Node} node
 * @returns {Node[]}
 */
export function textNodesUnder(node) {
    try {
        let all = [];
        for (node = node.firstChild; node; node = node.nextSibling) {
            if (node.nodeType === 3)
                all.push(node);
            else
                all = all.concat(textNodesUnder(node));
        }
        return all;
    }
    catch (error) {
        //
    }
}
/**
 * Adds the style for the mark element.
 *
 */
function addStyles() {
    const styleId = 'webHighlightsGlobalStyling';
    if (!document.getElementById(styleId)) {
        const style = document.createElement('style');
        style.id = styleId;
        style.innerHTML = `
        mark, span.highlight {
          border-radius: 3px;
          background-color: #92ffaa;
        }

        mark > *:not(my-marker) {
          background-color: #92ffaa;
        }
        `;
        document.body.appendChild(style);
    }
}
//# sourceMappingURL=markerHelper.js.map