var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { TagsService } from './tags.service';
import { store } from './../store/store';
import { updateBookmark, addBookmark, removeBookmark, initBookmarks } from '../store/actions';
import { v4 as uuid } from 'uuid';
import { MarkerService } from './marker.service';
import { getTitleForBookmark } from '../helper/bookmarkHelper';
import httpClient from './http-client';
import httpFacade from './http-facade';
import { handlePaymentRequired, isPaymentRequiredError } from '../helper/paymentRequired';
export class BookmarkService {
    constructor() {
        this.tagsService = new TagsService();
        this.BASE_URL = '/bookmarks';
    }
    getBookmarks() {
        return __awaiter(this, void 0, void 0, function* () {
            const bookmarks = yield httpFacade.getData('/bookmarks');
            initBookmarks(bookmarks);
            return bookmarks;
        });
    }
    getBookmarkForUrl(url) {
        return __awaiter(this, void 0, void 0, function* () {
            const bookmark = yield httpClient.get({ url: this.BASE_URL + '/url?url=' + url });
            return bookmark;
        });
    }
    createBookmark(bookmark) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // Update redux
                addBookmark(bookmark);
                const createdBookmark = yield httpClient.post({ url: this.BASE_URL, body: bookmark });
                return createdBookmark;
            }
            catch (error) {
                if (isPaymentRequiredError(error)) {
                    removeBookmark(bookmark.id);
                    handlePaymentRequired(error);
                }
            }
        });
    }
    deleteBookmark(bookmarkId) {
        return __awaiter(this, void 0, void 0, function* () {
            // Update redux
            removeBookmark(bookmarkId);
            yield httpClient.delete({ url: this.BASE_URL + '/' + bookmarkId });
        });
    }
    updateBookmark(bookmark) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // Update redux
                updateBookmark(bookmark);
                //await this.updateTagsOfRelatedMarks(bookmark);
                yield httpClient.put({ url: this.BASE_URL, body: bookmark });
                yield this.updateRelatedMarks(bookmark);
                // Update bookmarks for store
                yield this.getBookmarks();
                // Update tags for store
                yield this.tagsService.getTags();
            }
            catch (error) {
                if (isPaymentRequiredError(error)) {
                    handlePaymentRequired(error);
                }
            }
        });
    }
    getBookmarkById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield httpClient.get({ url: this.BASE_URL + '/' + id });
            const bookmark = response;
            return bookmark;
        });
    }
    createNewBookmark(isStarred) {
        return {
            id: uuid(),
            createdAt: new Date().getTime(),
            url: location.href,
            isStarred: isStarred,
            tags: [],
            title: getTitleForBookmark(),
            origin: location.origin
        };
    }
    /**
     * If tags of bookmark are changing they also have to be stored and saved in mark
     *
     * @param {Bookmark} bookmark
     * @memberof BookmarkService
     */
    updateRelatedMarks(bookmark) {
        return __awaiter(this, void 0, void 0, function* () {
            const markService = new MarkerService();
            const marks = store.getState().marks.filter(mark => mark.url === bookmark.url);
            marks.forEach((mark) => __awaiter(this, void 0, void 0, function* () { return yield markService.updateMark(mark); }));
        });
    }
}
//# sourceMappingURL=bookmark.service.js.map