var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import jwt_decode from 'jwt-decode';
import { login, logout } from '../store/actions';
import { JwtService } from '@marius-bronko/jwt-service';
export class ChromeJwtService extends JwtService {
    constructor() {
        super('jwt_webmarker');
    }
    getJwt() {
        const _super = Object.create(null, {
            getJwt: { get: () => super.getJwt }
        });
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((res) => {
                try {
                    chrome.storage.sync.get((items) => {
                        res(items['jwt_key']);
                    });
                }
                catch (error) {
                    let jwt = _super.getJwt.call(this);
                    jwt ? res(jwt) : res('');
                }
            });
        });
    }
    /**
     * Tries to get the jwt-token either from the chrome storage or localstorage
     *
     * @returns {Promise<JwtPayload>}
     * @memberof JwtService
     */
    getJwtPayload() {
        const _super = Object.create(null, {
            getJwtPayload: { get: () => super.getJwtPayload }
        });
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((res) => __awaiter(this, void 0, void 0, function* () {
                try {
                    chrome.storage.sync.get((items) => {
                        let payload;
                        try {
                            payload = jwt_decode(items['jwt_key']);
                        }
                        catch (error) {
                            res(undefined);
                        }
                        login(payload);
                        res(payload);
                    });
                }
                catch (error) {
                    try {
                        const payload = yield _super.getJwtPayload.call(this);
                        payload ? login(payload) : logout();
                        payload ? res(payload) : res(undefined);
                    }
                    catch (error) {
                        res(undefined);
                    }
                }
            }));
        });
    }
    setJwt(jwt) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                localStorage[this.key] = jwt;
                chrome.storage.sync.set({ jwt_key: jwt });
            }
            catch (error) {
                //
            }
        });
    }
}
const chromeJwtService = new ChromeJwtService();
export default chromeJwtService;
//# sourceMappingURL=chrome-jwt.service.js.map