var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { v4 as uuidv4 } from 'uuid';
import { initDirectories, addDirectory, removeDirectory, updateDirectory, addTag } from '../store/actions';
import httpClient from './http-client';
import httpFacade from './http-facade';
export class DirectoryService {
    constructor() {
        this.BASE_URL = '/directory';
    }
    getDirectories() {
        return __awaiter(this, void 0, void 0, function* () {
            const directories = yield httpFacade.getData('/directory');
            initDirectories(directories);
            return directories;
        });
    }
    createDirectory(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            const newDirectory = Object.assign(Object.assign({}, directory), { id: uuidv4() });
            const createdDirectory = yield httpClient.post({ url: this.BASE_URL, body: newDirectory });
            // Update redux
            addDirectory(createdDirectory);
            // Create tag for directory
            addTag(createdDirectory.name, createdDirectory._id);
            return createdDirectory;
        });
    }
    deleteDirectory(directoryId) {
        return __awaiter(this, void 0, void 0, function* () {
            // Update redux
            removeDirectory(directoryId);
            yield httpClient.delete({ url: this.BASE_URL + '/' + directoryId });
        });
    }
    updateDirectory(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            // Update redux
            updateDirectory(directory);
            yield httpClient.put({ url: this.BASE_URL, body: directory });
            // Update directories for store
            yield this.getDirectories();
        });
    }
    getDirectoryById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const directory = yield httpClient.get({ url: this.BASE_URL + '/' + id });
            return directory;
        });
    }
}
//# sourceMappingURL=directory.service.js.map