var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { TagsService } from './tags.service';
import { store } from './../store/store';
import { BookmarkService } from './bookmark.service';
import { addMark, removeMark, updateMark, initMarks, logout } from '../store/actions';
import httpClient from './http-client';
import httpFacade from './http-facade';
import { handlePaymentRequired, isPaymentRequiredError } from '../helper/paymentRequired';
export class MarkerService {
    constructor() {
        this.bookmarkService = new BookmarkService();
        this.tagsService = new TagsService();
    }
    getMarks() {
        return __awaiter(this, void 0, void 0, function* () {
            const marks = yield httpFacade.getData('/marks');
            initMarks(marks);
            return marks;
        });
    }
    getMarksForUrl(url) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return httpClient.get({ url: '/marks/url?url=' + url });
            }
            catch (error) {
                logout();
                return undefined;
            }
        });
    }
    createMark(mark) {
        return __awaiter(this, void 0, void 0, function* () {
            mark = this.addTagsOfBookmark(mark);
            addMark(mark);
            try {
                const createdMark = yield httpClient.post({ url: '/marks', body: mark });
                updateMark(createdMark);
                // Reload bookmarks to update for changes (If first mark on page is made, bookmark will be created)
                yield this.bookmarkService.getBookmarks();
                return createdMark;
            }
            catch (error) {
                if (isPaymentRequiredError(error)) {
                    removeMark(mark.id);
                    handlePaymentRequired(error);
                }
            }
        });
    }
    deleteMark(markId) {
        return __awaiter(this, void 0, void 0, function* () {
            removeMark(markId);
            yield httpClient.delete({ url: '/marks/' + markId });
            // Reload bookmarks to update for changes (If last mark gets deleted, bookmark will be deleted if not starred)
            yield this.bookmarkService.getBookmarks();
        });
    }
    updateMark(mark) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                updateMark(mark);
                yield httpClient.put({ url: '/marks', body: mark });
                yield this.tagsService.getTags();
            }
            catch (error) {
                if (isPaymentRequiredError(error)) {
                    handlePaymentRequired(error);
                }
            }
        });
    }
    getMarkById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return httpClient.get({ url: '/marks/' + id });
        });
    }
    /**
     * Adds the tags of the current bookmark to the created mark
     *
     * @param {Mark} mark
     * @memberof MarkerService
     */
    addTagsOfBookmark(mark) {
        try {
            const bookmark = store.getState().bookmarks.find(bookmark => bookmark.url === mark.url);
            if (bookmark && bookmark.tags)
                mark.tags = [...new Set([...mark.tags, ...bookmark.tags])];
        }
        catch (error) {
            //
        }
        return mark;
    }
}
//# sourceMappingURL=marker.service.js.map