var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { store } from './../store/store';
import { initTags } from '../store/actions';
import httpClient from './http-client';
import httpFacade from './http-facade';
export class TagsService {
    constructor() {
        this.BASE_URL = '/tags';
    }
    getTagsFromMarksAndBookmarks() {
        let tags = [];
        store.getState().marks.forEach(mark => {
            tags = [...tags, ...mark.tags];
        });
        store.getState().bookmarks.forEach(bookmark => {
            tags = [...tags, ...bookmark.tags];
        });
        tags = [...new Set(tags)].filter(tag => tag.toLowerCase().includes(store.getState().searchValue.toLowerCase()));
        tags.sort((a, b) => a.localeCompare(b, undefined, { sensitivity: 'base' }));
        return tags;
    }
    getTags() {
        return __awaiter(this, void 0, void 0, function* () {
            const tags = yield httpFacade.getData('/tags');
            initTags(tags);
            return tags;
        });
    }
    /**
     * Updates a tag and reloads all tags from server for state management
     *
     * @param {Tag} tag
     * @memberof TagsService
     */
    updateTag(tag) {
        return __awaiter(this, void 0, void 0, function* () {
            yield httpClient.put({ url: this.BASE_URL, body: tag });
            yield this.getTags();
        });
    }
}
//# sourceMappingURL=tags.service.js.map