var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { login, logout } from '../store/actions';
import httpClient from './http-client';
import chromeJwtService from './chrome-jwt.service';
export class UserService {
    /**
     * Signs the user in and saves the result in the chromeJwtService.
     *
     * @returns {Promise<string>}
     * @memberof UserService
     */
    login(loginUserDto) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield httpClient.post({ url: '/auth', body: loginUserDto });
            yield chromeJwtService.setJwt(result.token);
            const jwtPayload = yield chromeJwtService.getJwtPayload();
            if (result.token)
                login(jwtPayload);
            return result.token;
        });
    }
    /**
     * Signs up the user. A jwt token will be the result so that the user gets logged in directly
     *
     * @returns {Promise<string>}
     * @memberof UserService
     */
    register(signUpUserDto) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield httpClient.post({ url: '/users/register', body: signUpUserDto });
            yield chromeJwtService.setJwt(result.token);
            const jwtPayload = yield chromeJwtService.getJwtPayload();
            if (jwtPayload)
                login(jwtPayload);
            return result.token;
        });
    }
    resendEmailConfirmationLink(email) {
        return __awaiter(this, void 0, void 0, function* () {
            yield httpClient.post({ url: `/users/resend-email-confirmation?email=${email}`, body: {} });
        });
    }
    resetPassword(email) {
        return __awaiter(this, void 0, void 0, function* () {
            return httpClient.post({ url: `/users/reset-password?email=${email}`, body: {} });
        });
    }
    logout() {
        return __awaiter(this, void 0, void 0, function* () {
            chromeJwtService.setJwt('');
            logout();
        });
    }
}
//# sourceMappingURL=user.service.js.map